SmartDateOptionsConfig class

The parameters passed as input to the date input

Constructors

SmartDateOptionsConfig.flexiDate({IRef? contact, List<IFact> facts = const [], List<DateRef>? defaultDates, DateRef? defaultDate, bool? showAlert})
const
SmartDateOptionsConfig.of({required bool isFlexiDate, required IRef? contact, required List<IFact>? facts, required List<DateRef>? defaultDates, required DateRef? defaultDate, required bool? showAlert})
const

Properties

contact → IRef?
final
defaultDate → DateRef?
final
defaultDates → List<DateRef>
no setter
facts → List<IFact>
no setter
hashCode → int
The hash code for this object.
no setterinherited
isFlexiDate → bool
no setter
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAlert → bool
no setter
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copy({bool? isFlexiDate, IRef? contact, List<IFact>? facts, List<DateRef>? defaultDates, DateRef? defaultDate, bool? showAlert}) → SmartDateOptionsConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator +(SmartDateOptionsConfig other) → SmartDateOptionsConfig
operator ==(Object other) → bool
The equality operator.
inherited