MediaSource<F> class abstract

Implementers

Constructors

MediaSource()

Properties

diffHashCode → int
no setterinherited
diffKey → dynamic
no setterinherited
diffSource → dynamic
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
ready → FutureOr
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

diffEquals(dynamic other) → bool
inherited
diffIdentical(dynamic other) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited