MetaFormFieldContext class

Constructors

MetaFormFieldContext({required MetaFormContext form, Map<String, dynamic>? data, HandledPaths? renderer, required List<MetaFieldConfig> formConfig, required JsonPath fullPath, required IMSchemaProperty property})
MetaFormFieldContext.noop(BuildContext context, MSchemaRef emptyRef)

Properties

data → Map<String, dynamic>
final
extraHandlers → List<IMetaPropertyHandler>
no setteroverride
form → MetaFormContext
final
fullPath → JsonPath
final
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool?
no setter
overrides → MetadataOverrides
no setteroverride
property ↔ IMSchemaProperty?
getter/setter pair
renderer → HandledPaths?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

formConfig<T extends MetaFieldConfig>() → T?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveLabel({String? labelOverride, IMSchemaProperty? prop, String? fallbackLabel}) → String?
resolvePlaceholder({String? placeholderOverride}) → String?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited