MetaFormSection class

Constructors

MetaFormSection({String? label, String? key, required Set properties})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
isNotEmpty → bool
no setter
key → String?
final
label → String?
final
properties → Set<JsonPath>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

filtered(Set<JsonPath> against) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator +(JsonPath property) → dynamic
operator ==(Object other) → bool
The equality operator.
inherited