FactSmartDateQueryResult class

The result of a smartDate query that was based on a fact.

Implemented types
Mixed-in types
Available extensions

Constructors

FactSmartDateQueryResult.ofMetaData(IFactSchema schema, IFactMetaDate metaDate, IFact fact, IRef contact, {TZDateTime? resultDate, Location? location})
FactSmartDateQueryResult.ofQuerySource(FactSmartDateQuerySource source, DateTime resultDate, FlexiDate? flexiDate, [ISmartDate? smartDate])

Properties

flexiDate → FlexiDate
The resolved date, as a FlexiDate
final
formattedDate → String?

Available on SmartDateQueryResult, provided by the SmartDateQueryResultExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasTime → bool?
no setterinherited
icon → String?
no setteroverride
isCard → bool
no setterinherited
isFlexible → bool
Whether the result is a FlexiDate. If true, then flexiDate should not be null. If false, then resultDate should not be null
final
isRecurring → bool?
Whether or not we should automatically set this to recurring
final
isResolved → bool
Whether the query resolved to an actual date
no setteroverride
isTimeInferred → bool
Whether the result date has an inferred time.
final
labeledFact → LabeledFact?
no setter
overrideTitle ↔ String?
getter/setter pair
recurrence → TimeSpan?
Returns the suggested recurrence for this result. This doesn't necessarily mean that the result should be interpreted as recurring. See isRecurring
final
remindLabel → String?
no setter
resultDate → DateTime
The resolved date
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection → String?
What gets put back into the search box when this item is selected
final
shouldDisplayTime → bool

Available on SmartDateQueryResult, provided by the SmartDateQueryResultExtension extension

no setter
smartDateQuery → String?
The query that was sent to the SmartDateService
no setteroverride
source → FactSmartDateQuerySource
final
sourceFact → IFact?
no setter
subtitle → List
no setteroverride
title → String?
no setteroverride
trailing → dynamic
Action text to display in the trailing section;
no setterinherited

Methods

buildListTile(BuildContext context, {bool? isCard, VoidCallback? onTap}) → Widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSelected(BuildContext context) → FutureOr<SmartDateQueryResult?>
inherited
toDueConfig() → ITaskDueConfig
override
toListTile(BuildContext context, {Key? key, bool? isCard, double iconSize = 30, VoidCallback? onTap}) → Widget
inherited
toOption() → Option<SmartDateQueryResult>
inherited
toString() → String
A string representation of this object.
inherited
withDateRef(DateRef ref) → SmartDateQueryResult

Available on SmartDateQueryResult, provided by the SmartDateQueryResultDateRefExtensions extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited