UnresolvedFactDateQueryResult class

This query wasn't sent to the server, but still represents something we want to show the user. This means that we found a fact name, but the focused contact (or other scope) doesn't contain an actual date.

The user will likely be prompted to add the appropriate date

Implemented types
Mixed-in types
Available extensions

Constructors

UnresolvedFactDateQueryResult(IFactSchema factSchema, IFactMetaDate metaDate, IRef contact, {String? originalQuery, String? matchedTerm, String? smartDateQuery})
UnresolvedFactDateQueryResult.ofSchemaQuery(FactDateSchemaQuery source, IRef contact)

Properties

contact → IRef
final
factSchema → IFactSchema
final
flexiDate → FlexiDate?
The resolved date, as a FlexiDate
no setteroverride
formattedDate → String?

Available on SmartDateQueryResult, provided by the SmartDateQueryResultExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasTime → bool?
no setterinherited
icon → String?
no setteroverride
isCard → bool
no setterinherited
isFlexible → bool
Whether the result is a FlexiDate. If true, then flexiDate should not be null. If false, then resultDate should not be null
no setteroverride
isRecurring → bool?
Whether or not we should automatically set this to recurring
no setteroverride
isResolved → bool
Whether the query resolved to an actual date
no setteroverride
isTimeInferred → bool
Whether the result date has an inferred time.
no setteroverride
matchedTerm → String?
final
metaDate → IFactMetaDate
final
originalQuery → String?
final
recurrence → TimeSpan?
Returns the suggested recurrence for this result. This doesn't necessarily mean that the result should be interpreted as recurring. See isRecurring
no setteroverride
resultDate → DateTime?
The resolved date
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection → String?
What gets put back into the search box when this item is selected
no setteroverride
shouldDisplayTime → bool

Available on SmartDateQueryResult, provided by the SmartDateQueryResultExtension extension

no setter
smartDateQuery → String?
The query that was sent to the SmartDateService
final
subtitle → List?
no setteroverride
title → String
no setteroverride
trailing → dynamic
Action text to display in the trailing section;
no setterinherited

Methods

buildListTile(BuildContext context, {bool? isCard, VoidCallback? onTap}) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSelected(BuildContext context) → FutureOr<SmartDateQueryResult?>
override
toDueConfig() → ITaskDueConfig
override
toListTile(BuildContext context, {Key? key, bool? isCard, double iconSize = 30, VoidCallback? onTap}) → Widget
inherited
toOption() → Option<SmartDateQueryResult>
inherited
toString() → String
A string representation of this object.
inherited
withDateRef(DateRef ref) → SmartDateQueryResult

Available on SmartDateQueryResult, provided by the SmartDateQueryResultDateRefExtensions extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited