SmartDateQuerySource class abstract

Represents a query to be sent to the SmartDateService - because of Fact dates, we may do some pre-processing to the query, which is why we subclass.

Implementers

Constructors

SmartDateQuerySource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smartDateQuery → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryResult(ISmartDate result) → List<SmartDateQueryResult>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited