Attribute<X> class

Constructors

Attribute(JsonPath<X>? path, X? value, {required AttributeSource source, bool clearErrors = false})
Attribute.control(JsonPath<X> path, X value)
Attribute.model(JsonPath<X> path, X value)
Attribute.ofError(JsonPath<X>? path, dynamic error, {required AttributeSource source})

Properties

clearErrors → bool
Used for the model to signal back to the control that an error has been cleared
final
error → dynamic
final
hashCode → int
The hash code for this object.
no setteroverride
isError → bool
no setter
path → JsonPath<X>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → AttributeSource
final
value → X?
final

Methods

cast<C>() → Attribute<C>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override