PlatformCardArgs class

Constructors

PlatformCardArgs({double? pressOpacity = 1, FutureTappableCallback? onHover, double? pressScale = Tappable.defaultScale, EdgeInsets? padding, EdgeInsets? margin, BorderRadius? borderRadius, Color? color, double? height, double? width, bool? useShadow = true, double? minWidth, PlatformCardTheme? theme, double? minHeight, FutureTappableCallback? onTap, bool? shouldClip, FutureTappableCallback? onLongPress, List<BoxShadow>? shadow})
const

Properties

borderRadius → BorderRadius?
final
color → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
margin → EdgeInsets?
final
minHeight → double?
final
minWidth → double?
final
onHover → FutureTappableCallback?
final
onLongPress → FutureTappableCallback?
final
onTap → FutureTappableCallback?
final
padding → EdgeInsets?
final
pressOpacity → double?
final
pressScale → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → List<BoxShadow>?
final
shouldClip → bool?
final
theme → PlatformCardTheme?
final
useShadow → bool?
final
width → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited